@@ -30,6 +30,7 @@
 #else /* !HAVE_ARGP_H */
 #include "freeipmi-argp.h"
 #endif /* !HAVE_ARGP_H */
+#include <assert.h>
 
 #include "bmc-config.h"
 #include "bmc-config-argp.h"
@@ -88,9 +89,13 @@ static struct argp cmdline_config_file_argp = { cmdline_options,
 static error_t
 cmdline_parse (int key, char *arg, struct argp_state *state)
 {
-  struct bmc_config_arguments *cmd_args = state->input;
+  struct bmc_config_arguments *cmd_args;
   error_t ret;
 
+  assert (state);
+  
+  cmd_args = state->input;
+
   switch (key)
     {
     case ARGP_KEY_ARG:
@@ -105,9 +110,7 @@ cmdline_parse (int key, char *arg, struct argp_state *state)
     default:
       ret = config_parse_opt (key, arg, &cmd_args->config_args);
       if (ret == ARGP_ERR_UNKNOWN)
-        ret = common_parse_opt (key, arg, &cmd_args->config_args.common);
-      if (ret == ARGP_ERR_UNKNOWN)
-        ret = hostrange_parse_opt (key, arg, &(cmd_args->config_args.hostrange));
+        ret = common_parse_opt (key, arg, &cmd_args->config_args.common_args);
       return (ret);
     }
   return (0);
@@ -118,21 +121,21 @@ _bmc_config_config_file_parse (struct bmc_config_arguments *cmd_args)
 {
   struct config_file_data_bmc_config config_file_data;
   
+  assert (cmd_args);
+
   memset (&config_file_data,
           '\0',
           sizeof (struct config_file_data_bmc_config));
   
-  if (config_file_parse (cmd_args->config_args.common.config_file,
+  if (config_file_parse (cmd_args->config_args.common_args.config_file,
                          0,
-                         &(cmd_args->config_args.common),
-                         NULL,
-                         &(cmd_args->config_args.hostrange),
+                         &(cmd_args->config_args.common_args),
                          CONFIG_FILE_INBAND | CONFIG_FILE_OUTOFBAND | CONFIG_FILE_HOSTRANGE,
                          CONFIG_FILE_TOOL_BMC_CONFIG,
                          &config_file_data) < 0)
     {
       fprintf (stderr, "config_file_parse: %s\n", strerror (errno));
-      exit (1);
+      exit (EXIT_FAILURE);
     }
 
   if (config_file_data.verbose_count_count)
@@ -142,11 +145,13 @@ _bmc_config_config_file_parse (struct bmc_config_arguments *cmd_args)
 static void
 _bmc_config_args_validate (struct bmc_config_arguments *cmd_args)
 {
+  assert (cmd_args);
+
   if (!cmd_args->config_args.action || cmd_args->config_args.action == -1)
     {
       fprintf (stderr,
                "Exactly one of --checkout, --commit, --diff, or --listsections MUST be given\n");
-      exit (1);
+      exit (EXIT_FAILURE);
     }
 
   config_args_validate (&(cmd_args->config_args));
@@ -156,16 +161,19 @@ _bmc_config_args_validate (struct bmc_config_arguments *cmd_args)
 void
 bmc_config_argp_parse (int argc, char *argv[], struct bmc_config_arguments *cmd_args)
 {
+  assert (argc >= 0);
+  assert (argv);
+  assert (cmd_args);
+
   init_config_args (&(cmd_args->config_args));
-  init_common_cmd_args_admin (&(cmd_args->config_args.common));
-  init_hostrange_cmd_args (&(cmd_args->config_args.hostrange));
+  init_common_cmd_args_admin (&(cmd_args->config_args.common_args));
 
   argp_parse (&cmdline_config_file_argp,
               argc,
               argv,
               ARGP_IN_ORDER,
               NULL,
-              &(cmd_args->config_args.common));
+              &(cmd_args->config_args.common_args));
 
   _bmc_config_config_file_parse (cmd_args);
 
@@ -176,6 +184,6 @@ bmc_config_argp_parse (int argc, char *argv[], struct bmc_config_arguments *cmd_
               NULL,
               cmd_args);
 
-  verify_common_cmd_args (&(cmd_args->config_args.common));
+  verify_common_cmd_args (&(cmd_args->config_args.common_args));
   _bmc_config_args_validate (cmd_args);
 }
