@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _CONFIG_TOOL_DIFF_H
-#define _CONFIG_TOOL_DIFF_H
+#ifndef CONFIG_TOOL_DIFF_H
+#define CONFIG_TOOL_DIFF_H
 
 #include "config-tool-common.h"
 #include "pstdout.h"
@@ -27,4 +27,4 @@ config_err_t config_diff (pstdout_state_t pstate,
                           struct config_arguments *cmd_args,
                           void *arg);
 
-#endif  /* _CONFIG_TOOL_DIFF_H */
+#endif /* CONFIG_TOOL_DIFF_H */
