@@ -578,6 +578,30 @@ _mandatory_platform_attributes (ipmi_dcmi_state_data_t *state_data)
                       val ? "At least 1 present" : "Not present");
     }
 
+  /* In DCMI v1.1 */
+  if (parameter_revision >= 0x02)
+    {
+      int flag;
+
+      if ((flag = fiid_obj_get (obj_cmd_rs,
+				"temperature_monitoring.sampling_period",
+				&val)) < 0)
+        {
+          pstdout_fprintf (state_data->pstate,
+                           stderr,
+                           "fiid_obj_get: 'temperature_monitoring.sampling_period': %s\n",
+                           fiid_obj_errormsg (obj_cmd_rs));
+          goto cleanup;
+        }
+
+      if (flag)
+        {
+          pstdout_printf (state_data->pstate,
+                      "Sampling frequency for Temperature Monitoring      : Every %u Second(s)\n",
+                      val);
+        }
+    }
+
   rv = 1;
  cleanup:
   fiid_obj_destroy (obj_cmd_rs);
@@ -1559,22 +1583,22 @@ _sensor_info_output (ipmi_dcmi_state_data_t *state_data,
           goto cleanup;
         }
 
-      if (number_of_record_ids_in_this_response != (sdr_record_ids_len / 2))
+      if (number_of_record_ids_in_this_response > (sdr_record_ids_len / 2))
         {
           pstdout_fprintf (state_data->pstate,
                            stderr,
-                           "invalid sdr_record_ids returned: %u != %u\n",
+                           "invalid sdr_record_ids returned: %u > %u\n",
                            number_of_record_ids_in_this_response,
                            (sdr_record_ids_len / 2));
           goto cleanup;
         }
 
-      for (i = 0; i < (sdr_record_ids_len / 2); i += 2)
+      for (i = 0; i < (number_of_record_ids_in_this_response * 2); i += 2)
         {
           uint16_t record_id = 0;
           
-          record_id |= sdr_record_ids[0];
-          record_id |= (sdr_record_ids[1] << 8);
+          record_id |= sdr_record_ids[i];
+          record_id |= (sdr_record_ids[i+1] << 8);
           
           pstdout_printf (state_data->pstate,
                           "%u\n",
