@@ -39,74 +39,45 @@
 #include "tool-sdr-cache-common.h"
 #include "tool-sensor-common.h"
 
-#define IPMI_OEM_SUN_LED_TYPE_OK2RM    0
-#define IPMI_OEM_SUN_LED_TYPE_SERVICE  1
-#define IPMI_OEM_SUN_LED_TYPE_ACTIVITY 2
-#define IPMI_OEM_SUN_LED_TYPE_LOCATE   3
-
-#define IPMI_OEM_SUN_LED_MODE_OFF     0
-#define IPMI_OEM_SUN_LED_MODE_ON      1
-#define IPMI_OEM_SUN_LED_MODE_STANDBY 2
-#define IPMI_OEM_SUN_LED_MODE_SLOW    3
-#define IPMI_OEM_SUN_LED_MODE_FAST    4
-
-#define IPMI_OEM_SUN_LED_FORCE_GO_THRU_CONTROLLER     0
-#define IPMI_OEM_SUN_LED_FORCE_DIRECTLY_ACCESS_DEVICE 1
-
 #define IPMI_SDR_RECORD_GENERIC_DEVICE_LOCATOR_DEVICE_ACCESS_ADDRESS_INDEX 5
 #define IPMI_SDR_RECORD_GENERIC_DEVICE_LOCATOR_DEVICE_SLAVE_ADDRESS_INDEX  6
 #define IPMI_SDR_RECORD_GENERIC_DEVICE_LOCATOR_OEM_INDEX                   14
 
-int
-ipmi_oem_sun_get_led (ipmi_oem_state_data_t *state_data)
+struct ipmi_oem_sun_get_led_sdr_callback
 {
-  struct sensor_entity_id_counts entity_id_counts;
-  struct sensor_entity_id_counts *entity_ptr = NULL;
-  struct sensor_column_width column_width;
-  uint16_t record_count;
-  int rv = -1;
-  int header_output_flag = 0;
-  int i;
-  
-  assert (state_data);
-  assert (!state_data->prog_data->args->oem_options_count);
+  ipmi_oem_state_data_t *state_data;
+  struct sensor_column_width *column_width;
+  int header_output_flag;
+};
 
-  if (sdr_cache_create_and_load (state_data->sdr_cache_ctx,
-                                 state_data->pstate,
-                                 state_data->ipmi_ctx,
-                                 state_data->prog_data->args->sdr.quiet_cache,
-                                 state_data->prog_data->args->sdr.sdr_cache_recreate,
-                                 state_data->hostname,
-                                 state_data->prog_data->args->sdr.sdr_cache_directory,
-                                 state_data->prog_data->args->sdr.sdr_cache_file) < 0)
-    goto cleanup;
+static int
+_sun_get_led_sdr_callback (ipmi_sdr_ctx_t sdr_ctx,
+			   uint8_t record_type,
+			   const void *sdr_record,
+			   unsigned int sdr_record_len,
+			   void *arg)
+{
+  struct ipmi_oem_sun_get_led_sdr_callback *sdr_callback_arg;
+  ipmi_oem_state_data_t *state_data;
+  uint8_t bytes_rq[IPMI_OEM_MAX_BYTES];
+  uint8_t bytes_rs[IPMI_OEM_MAX_BYTES];
+  int rs_len;
+  uint16_t record_id;
+  char fmt[IPMI_OEM_FMT_BUFLEN + 1];
+  char device_id_string[IPMI_SDR_MAX_DEVICE_ID_STRING_LENGTH + 1];
+  char sensor_name_buf[IPMI_SDR_MAX_SENSOR_NAME_LENGTH + 1];
+  char *sensor_name = NULL;
+  uint8_t entity_instance_type;
+  uint8_t led_mode;
+  char *led_mode_str = NULL;
 
-  if (state_data->prog_data->args->verbose_count)
-    {
-      if (calculate_entity_id_counts (state_data->pstate,
-                                      state_data->sdr_cache_ctx,
-                                      state_data->sdr_parse_ctx,
-                                      &entity_id_counts) < 0)
-        goto cleanup;
+  assert (sdr_ctx);
+  assert (sdr_record);
+  assert (sdr_record_len);
+  assert (arg);
 
-      entity_ptr = &entity_id_counts;
-    }
-
-  if (calculate_column_widths (state_data->pstate,
-                               state_data->sdr_cache_ctx,
-                               state_data->sdr_parse_ctx,
-                               NULL,
-                               0,
-                               NULL,
-                               0,
-                               0, /* non_abbreviated_units */
-                               0, /* shared_sensors */
-                               0, /* count_event_only_records */
-                               1, /* count_device_locator_records */
-                               0, /* count_oem_records */
-                               entity_ptr,
-                               &column_width) < 0)
-    goto cleanup;
+  sdr_callback_arg = (struct ipmi_oem_sun_get_led_sdr_callback *)arg;
+  state_data = sdr_callback_arg->state_data;
 
   /* Sun OEM
    *
@@ -120,6 +91,10 @@ ipmi_oem_sun_get_led (ipmi_oem_state_data_t *state_data)
    *      - Note that the IPMI command requires the entire
    *        byte of the slave address.
    * 0x?? - LED Type (see below [1])
+   *      - 0 - ok2rm
+   *      - 1 - service
+   *      - 2 - activity
+   *      - 3 - locate 
    * 0x?? - Controller Address / Device Access Address (in General Device Locator Record)
    *      - 0x20 if the LED is local
    *      - Note that the IPMI command requires the entire
@@ -163,202 +138,225 @@ ipmi_oem_sun_get_led (ipmi_oem_state_data_t *state_data)
    * in ipmitool and set this field to the OEM field.
    */
 
-  if (ipmi_sdr_cache_record_count (state_data->sdr_cache_ctx, &record_count) < 0)
+  if (record_type != IPMI_SDR_FORMAT_GENERIC_DEVICE_LOCATOR_RECORD)
+    return (0);
+
+  if (ipmi_sdr_parse_entity_id_instance_type (state_data->sdr_ctx,
+					      sdr_record,
+					      sdr_record_len,
+					      NULL,
+					      NULL,
+					      &entity_instance_type) < 0)
     {
       pstdout_fprintf (state_data->pstate,
 		       stderr,
-		       "ipmi_sdr_cache_record_count: %s\n",
-		       ipmi_sdr_cache_ctx_errormsg (state_data->sdr_cache_ctx));
-      goto cleanup;
+		       "ipmi_sdr_parse_entity_id_and_instance: %s\n",
+		       ipmi_sdr_ctx_errormsg (state_data->sdr_ctx));
+      return (-1);
+    }
+      
+  /* if it isn't a physical instance, don't continue on */
+
+  if (entity_instance_type == IPMI_SDR_LOGICAL_CONTAINER_ENTITY)
+    return (0);
+          
+  if (ipmi_sdr_parse_record_id_and_type (state_data->sdr_ctx,
+					 sdr_record,
+					 sdr_record_len,
+					 &record_id,
+					 NULL) < 0)
+    {
+      pstdout_fprintf (state_data->pstate,
+		       stderr,
+		       "ipmi_sdr_parse_record_id_and_type: %s\n",
+		       ipmi_sdr_ctx_errormsg (state_data->sdr_ctx));
+      return (-1);
     }
 
-  for (i = 0; i < record_count; i++, ipmi_sdr_cache_next (state_data->sdr_cache_ctx))
+  /* achu: the sun oem commands want the full byte, not just the
+   * sub-field, so use indexes instead of sdr-parse lib.
+   */
+
+  bytes_rq[0] = IPMI_CMD_OEM_SUN_GET_LED;
+  bytes_rq[1] = ((uint8_t *)sdr_record)[IPMI_SDR_RECORD_GENERIC_DEVICE_LOCATOR_DEVICE_SLAVE_ADDRESS_INDEX];
+  bytes_rq[2] = ((uint8_t *)sdr_record)[IPMI_SDR_RECORD_GENERIC_DEVICE_LOCATOR_OEM_INDEX];
+  bytes_rq[3] = ((uint8_t *)sdr_record)[IPMI_SDR_RECORD_GENERIC_DEVICE_LOCATOR_DEVICE_ACCESS_ADDRESS_INDEX];
+  bytes_rq[4] = ((uint8_t *)sdr_record)[IPMI_SDR_RECORD_GENERIC_DEVICE_LOCATOR_OEM_INDEX];
+  bytes_rq[5] = IPMI_OEM_SUN_LED_FORCE_GO_THRU_CONTROLLER;
+
+  if ((rs_len = ipmi_cmd_raw (state_data->ipmi_ctx,
+			      0, /* lun */
+			      IPMI_NET_FN_OEM_GROUP_RQ, /* network function */
+			      bytes_rq, /* data */
+			      6, /* num bytes */
+			      bytes_rs,
+			      IPMI_OEM_MAX_BYTES)) < 0)
     {
-      uint8_t bytes_rq[IPMI_OEM_MAX_BYTES];
-      uint8_t bytes_rs[IPMI_OEM_MAX_BYTES];
-      int rs_len;
-      uint8_t sdr_record[IPMI_SDR_CACHE_MAX_SDR_RECORD_LENGTH];
-      int sdr_record_len = 0;
-      uint16_t record_id;
-      uint8_t record_type;
-      char fmt[IPMI_OEM_FMT_BUFLEN + 1];
-      char device_id_string[IPMI_SDR_CACHE_MAX_DEVICE_ID_STRING + 1];
-      char sensor_name_buf[MAX_ENTITY_ID_SENSOR_NAME_STRING + 1];
-      char *sensor_name = NULL;
-      uint8_t entity_instance_type;
-      uint8_t led_mode;
-      char *led_mode_str = NULL;
+      pstdout_fprintf (state_data->pstate,
+		       stderr,
+		       "ipmi_cmd_raw: %s\n",
+		       ipmi_ctx_errormsg (state_data->ipmi_ctx));
+      return (-1);
+    }
+  
+  /* achu: there are probably 1 or 2 completion codes that are
+   * acceptable to ignore and continue on, but who knows what they
+   * are.
+   */
 
-      if ((sdr_record_len = ipmi_sdr_cache_record_read (state_data->sdr_cache_ctx,
-							sdr_record,
-							IPMI_SDR_CACHE_MAX_SDR_RECORD_LENGTH)) < 0)
-	{
-	  pstdout_fprintf (state_data->pstate,
-			   stderr,
-			   "ipmi_sdr_cache_record_read: %s\n",
-			   ipmi_sdr_cache_ctx_errormsg (state_data->sdr_cache_ctx));
-	  goto cleanup;
-	}
-      
-      if (ipmi_sdr_parse_record_id_and_type (state_data->sdr_parse_ctx,
-					     sdr_record,
-					     sdr_record_len,
-					     &record_id,
-					     &record_type) < 0)
-	{
-	  pstdout_fprintf (state_data->pstate,
-			   stderr,
-			   "ipmi_sdr_parse_record_id_and_type: %s\n",
-			   ipmi_sdr_parse_ctx_errormsg (state_data->sdr_parse_ctx));
-	  goto cleanup;
-	}
-      
-      
-      if (record_type != IPMI_SDR_FORMAT_GENERIC_DEVICE_LOCATOR_RECORD)
-        continue;
-
-      if (ipmi_sdr_parse_entity_id_instance_type (state_data->sdr_parse_ctx,
-                                                  sdr_record,
-                                                  sdr_record_len,
-                                                  NULL,
-                                                  NULL,
-                                                  &entity_instance_type) < 0)
-        {
-          pstdout_fprintf (state_data->pstate,
-                           stderr,
-                           "ipmi_sdr_parse_entity_id_and_instance: %s\n",
-                           ipmi_sdr_parse_ctx_errormsg (state_data->sdr_parse_ctx));
-          goto cleanup;
-        }
-      
-      /* if it isn't a physical instance, don't continue on */
-
-      if (entity_instance_type == IPMI_SDR_LOGICAL_CONTAINER_ENTITY)
-        continue;
-          
-      /* achu: the sun oem commands want the full byte, not just the
-       * sub-field, so use indexes instead of sdr-parse lib.
-       */
-
-      bytes_rq[0] = IPMI_CMD_OEM_SUN_GET_LED;
-      bytes_rq[1] = sdr_record[IPMI_SDR_RECORD_GENERIC_DEVICE_LOCATOR_DEVICE_SLAVE_ADDRESS_INDEX];
-      bytes_rq[2] = sdr_record[IPMI_SDR_RECORD_GENERIC_DEVICE_LOCATOR_OEM_INDEX];
-      bytes_rq[3] = sdr_record[IPMI_SDR_RECORD_GENERIC_DEVICE_LOCATOR_DEVICE_ACCESS_ADDRESS_INDEX];
-      bytes_rq[4] = sdr_record[IPMI_SDR_RECORD_GENERIC_DEVICE_LOCATOR_OEM_INDEX];
-      bytes_rq[5] = IPMI_OEM_SUN_LED_FORCE_GO_THRU_CONTROLLER;
-
-      if ((rs_len = ipmi_cmd_raw (state_data->ipmi_ctx,
-                                  0, /* lun */
-                                  IPMI_NET_FN_OEM_GROUP_RQ, /* network function */
-                                  bytes_rq, /* data */
-                                  6, /* num bytes */
-                                  bytes_rs,
-                                  IPMI_OEM_MAX_BYTES)) < 0)
-        {
-          pstdout_fprintf (state_data->pstate,
-                           stderr,
-                           "ipmi_cmd_raw: %s\n",
-                           ipmi_ctx_errormsg (state_data->ipmi_ctx));
-          goto cleanup;
-        }
-      
-      /* achu: there are probably 1 or 2 completion codes that are
-       * acceptable to ignore and continue on, but who knows what they
-       * are.
-       */
-
-      if (ipmi_oem_check_response_and_completion_code (state_data,
-                                                       bytes_rs,
-                                                       rs_len,
-                                                       3,
-                                                       IPMI_CMD_OEM_SUN_GET_LED,
-                                                       IPMI_NET_FN_OEM_GROUP_RS,
-                                                       NULL) < 0)
-        goto cleanup;
-      
-      if (!header_output_flag)
-        {
-          memset (fmt, '\0', IPMI_OEM_FMT_BUFLEN + 1);
-          
-          snprintf (fmt,
-                    IPMI_OEM_FMT_BUFLEN,
-                    "%%-%ds | %%-%ds | LED Mode\n",
-                    column_width.record_id,
-                    column_width.sensor_name);
-          
-          pstdout_printf (state_data->pstate,
-                          fmt,
-                          SENSORS_HEADER_RECORD_ID_STR,
-                          SENSORS_HEADER_NAME_STR);
-          
-          header_output_flag++;
-        }
-      
-      led_mode = bytes_rs[2];
-      
-      if (state_data->prog_data->args->verbose_count)
-        {
-          memset (sensor_name_buf, '\0', MAX_ENTITY_ID_SENSOR_NAME_STRING + 1);
-          
-          if (get_entity_sensor_name_string (state_data->pstate,
-                                             state_data->sdr_parse_ctx,
-                                             sdr_record,
-                                             sdr_record_len,
-                                             &entity_id_counts,
-                                             NULL,
-                                             sensor_name_buf,
-                                             MAX_ENTITY_ID_SENSOR_NAME_STRING) < 0)
-            goto cleanup;
-          
-          sensor_name = sensor_name_buf;
-        }
-      else
-        {
-          memset (device_id_string, '\0', IPMI_SDR_CACHE_MAX_DEVICE_ID_STRING + 1);
-          
-          if (ipmi_sdr_parse_device_id_string (state_data->sdr_parse_ctx,
-                                               sdr_record,
-                                               sdr_record_len,
-                                               device_id_string,
-                                               IPMI_SDR_CACHE_MAX_DEVICE_ID_STRING) < 0)
-            {
-              pstdout_fprintf (state_data->pstate,
-                               stderr,
-                               "ipmi_sdr_parse_device_id_string: %s\n",
-                               ipmi_sdr_parse_ctx_errormsg (state_data->sdr_parse_ctx));
-              goto cleanup;
-            }
-          
-          sensor_name = device_id_string;
-        }
-      
-      if (led_mode == IPMI_OEM_SUN_LED_MODE_OFF)
-        led_mode_str = "Off";
-      else if (led_mode == IPMI_OEM_SUN_LED_MODE_ON)
-        led_mode_str = "On";
-      else if (led_mode == IPMI_OEM_SUN_LED_MODE_STANDBY)
-        led_mode_str = "Standby";
-      else if (led_mode == IPMI_OEM_SUN_LED_MODE_SLOW)
-        led_mode_str = "Slow";
-      else if (led_mode == IPMI_OEM_SUN_LED_MODE_FAST)
-        led_mode_str = "Fast";
-      else
-        led_mode_str = "Unknown";
+  if (ipmi_oem_check_response_and_completion_code (state_data,
+						   bytes_rs,
+						   rs_len,
+						   3,
+						   IPMI_CMD_OEM_SUN_GET_LED,
+						   IPMI_NET_FN_OEM_GROUP_RS,
+						   NULL) < 0)
+    return (-1);
+  
+  if (!sdr_callback_arg->header_output_flag)
+    {
+      memset (fmt, '\0', IPMI_OEM_FMT_BUFLEN + 1);
       
       snprintf (fmt,
-                IPMI_OEM_FMT_BUFLEN,
-                "%%-%du | %%-%ds | %s\n",
-                column_width.record_id,
-                column_width.sensor_name,
-                led_mode_str);
+		IPMI_OEM_FMT_BUFLEN,
+		"%%-%ds | %%-%ds | LED Mode\n",
+		sdr_callback_arg->column_width->record_id,
+		sdr_callback_arg->column_width->sensor_name);
       
       pstdout_printf (state_data->pstate,
-                      fmt,
-                      record_id,
-                      sensor_name);
+		      fmt,
+		      SENSORS_HEADER_RECORD_ID_STR,
+		      SENSORS_HEADER_NAME_STR);
+          
+      sdr_callback_arg->header_output_flag++;
+    }
+      
+  led_mode = bytes_rs[2];
+      
+  if (state_data->prog_data->args->verbose_count)
+    {
+      memset (sensor_name_buf, '\0', IPMI_SDR_MAX_SENSOR_NAME_LENGTH + 1);
+      
+      if (ipmi_sdr_parse_entity_sensor_name (state_data->sdr_ctx,
+					     NULL,
+					     0,
+					     0, /* sensor number */
+					     IPMI_SDR_SENSOR_NAME_FLAGS_IGNORE_SHARED_SENSORS, /* flags */
+					     sensor_name_buf,
+					     IPMI_SDR_MAX_SENSOR_NAME_LENGTH) < 0)
+	{
+	  pstdout_fprintf (state_data->pstate,
+			   stderr,
+			   "ipmi_sdr_parse_entity_sensor_name: %s\n",
+			   ipmi_sdr_ctx_errormsg (state_data->sdr_ctx));
+	  return (-1);
+	}
+          
+      sensor_name = sensor_name_buf;
+    }
+  else
+    {
+      memset (device_id_string, '\0', IPMI_SDR_MAX_DEVICE_ID_STRING_LENGTH + 1);
+      
+      if (ipmi_sdr_parse_device_id_string (state_data->sdr_ctx,
+					   sdr_record,
+					   sdr_record_len,
+					   device_id_string,
+					   IPMI_SDR_MAX_DEVICE_ID_STRING_LENGTH) < 0)
+	{
+	  pstdout_fprintf (state_data->pstate,
+			   stderr,
+			   "ipmi_sdr_parse_device_id_string: %s\n",
+			   ipmi_sdr_ctx_errormsg (state_data->sdr_ctx));
+	  return (-1);
+	}
+      
+      sensor_name = device_id_string;
+    }
+      
+  switch (led_mode)
+    {
+    case IPMI_OEM_SUN_LED_MODE_OFF:
+      led_mode_str = "Off";
+      break;
+    case IPMI_OEM_SUN_LED_MODE_ON:
+      led_mode_str = "On";
+      break;
+    case IPMI_OEM_SUN_LED_MODE_STANDBY:
+      led_mode_str = "Standby";
+      break;
+    case IPMI_OEM_SUN_LED_MODE_SLOW:
+      led_mode_str = "Slow";
+      break;
+    case IPMI_OEM_SUN_LED_MODE_FAST:
+      led_mode_str = "Fast";
+      break;
+    default:
+      led_mode_str = "Unknown";
     }
   
+  snprintf (fmt,
+	    IPMI_OEM_FMT_BUFLEN,
+	    "%%-%du | %%-%ds | %s\n",
+	    sdr_callback_arg->column_width->record_id,
+	    sdr_callback_arg->column_width->sensor_name,
+	    led_mode_str);
+      
+  pstdout_printf (state_data->pstate,
+		  fmt,
+		  record_id,
+		  sensor_name);
+
+  return (0);
+}
+
+int
+ipmi_oem_sun_get_led (ipmi_oem_state_data_t *state_data)
+{
+  struct ipmi_oem_sun_get_led_sdr_callback sdr_callback_arg;
+  struct sensor_column_width column_width;
+  int rv = -1;
   
+  assert (state_data);
+  assert (!state_data->prog_data->args->oem_options_count);
+
+  if (sdr_cache_create_and_load (state_data->sdr_ctx,
+                                 state_data->pstate,
+                                 state_data->ipmi_ctx,
+                                 state_data->hostname,
+ 				 &state_data->prog_data->args->common_args) < 0)
+    goto cleanup;
+
+  if (calculate_column_widths (state_data->pstate,
+                               state_data->sdr_ctx,
+                               NULL,
+                               0,
+                               NULL,
+                               0,
+                               0, /* non_abbreviated_units */
+                               0, /* shared_sensors */
+                               0, /* count_event_only_records */
+                               1, /* count_device_locator_records */
+                               0, /* count_oem_records */
+                               state_data->prog_data->args->verbose_count,
+                               &column_width) < 0)
+    goto cleanup;
+
+  sdr_callback_arg.state_data = state_data;
+  sdr_callback_arg.column_width = &column_width;
+  sdr_callback_arg.header_output_flag = 0;
+
+  if (ipmi_sdr_cache_iterate (state_data->sdr_ctx,
+			      _sun_get_led_sdr_callback,
+			      &sdr_callback_arg) < 0)
+    {
+      pstdout_fprintf (state_data->pstate,
+		       stderr,
+		       "ipmi_sdr_cache_iterate: %s\n",
+		       ipmi_sdr_ctx_errormsg (state_data->sdr_ctx));
+      goto cleanup;
+    }
+ 
   rv = 0;
  cleanup:
   return (rv);
@@ -374,7 +372,7 @@ ipmi_oem_sun_set_led (ipmi_oem_state_data_t *state_data)
   uint8_t led_mode;
   long value;
   char *ptr;
-  uint8_t sdr_record[IPMI_SDR_CACHE_MAX_SDR_RECORD_LENGTH];
+  uint8_t sdr_record[IPMI_SDR_MAX_RECORD_LENGTH];
   int sdr_record_len = 0;
   uint8_t record_type;
   uint8_t entity_instance_type;
@@ -427,14 +425,11 @@ ipmi_oem_sun_set_led (ipmi_oem_state_data_t *state_data)
   else /* !strcasecmp (state_data->prog_data->args->oem_options[1], "fast") */
     led_mode = IPMI_OEM_SUN_LED_MODE_FAST;
 
-  if (sdr_cache_create_and_load (state_data->sdr_cache_ctx,
+  if (sdr_cache_create_and_load (state_data->sdr_ctx,
                                  state_data->pstate,
                                  state_data->ipmi_ctx,
-                                 state_data->prog_data->args->sdr.quiet_cache,
-                                 state_data->prog_data->args->sdr.sdr_cache_recreate,
                                  state_data->hostname,
-                                 state_data->prog_data->args->sdr.sdr_cache_directory,
-                                 state_data->prog_data->args->sdr.sdr_cache_file) < 0)
+ 				 &state_data->prog_data->args->common_args) < 0)
     goto cleanup;
 
   /* Sun OEM
@@ -449,6 +444,10 @@ ipmi_oem_sun_set_led (ipmi_oem_state_data_t *state_data)
    *      - Note that the IPMI command requires the entire
    *        byte of the slave address.
    * 0x?? - LED Type (see below [1])
+   *      - 0 - ok2rm
+   *      - 1 - service
+   *      - 2 - activity
+   *      - 3 - locate 
    * 0x?? - Controller Address / Device Access Address (in General Device Locator Record)
    *      - 0x20 if the LED is local
    *      - Note that the IPMI command requires the entire
@@ -499,28 +498,27 @@ ipmi_oem_sun_set_led (ipmi_oem_state_data_t *state_data)
    * in ipmitool and set this field to the OEM field.
    */
   
-  if (ipmi_sdr_cache_search_record_id (state_data->sdr_cache_ctx,
-                                       record_id) < 0)
+  if (ipmi_sdr_cache_search_record_id (state_data->sdr_ctx, record_id) < 0)
     {
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_sdr_cache_search_record_id: %s\n",
-                       ipmi_sdr_cache_ctx_errormsg (state_data->sdr_cache_ctx));
+                       ipmi_sdr_ctx_errormsg (state_data->sdr_ctx));
       goto cleanup;
     }
   
-  if ((sdr_record_len = ipmi_sdr_cache_record_read (state_data->sdr_cache_ctx,
+  if ((sdr_record_len = ipmi_sdr_cache_record_read (state_data->sdr_ctx,
                                                     sdr_record,
-                                                    IPMI_SDR_CACHE_MAX_SDR_RECORD_LENGTH)) < 0)
+                                                    IPMI_SDR_MAX_RECORD_LENGTH)) < 0)
     {
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_sdr_cache_record_read: %s\n",
-                       ipmi_sdr_cache_ctx_errormsg (state_data->sdr_cache_ctx));
+                       ipmi_sdr_ctx_errormsg (state_data->sdr_ctx));
       goto cleanup;
     }
   
-  if (ipmi_sdr_parse_record_id_and_type (state_data->sdr_parse_ctx,
+  if (ipmi_sdr_parse_record_id_and_type (state_data->sdr_ctx,
                                          sdr_record,
                                          sdr_record_len,
                                          NULL,
@@ -529,7 +527,7 @@ ipmi_oem_sun_set_led (ipmi_oem_state_data_t *state_data)
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_sdr_parse_record_id_and_type: %s\n",
-                       ipmi_sdr_parse_ctx_errormsg (state_data->sdr_parse_ctx));
+                       ipmi_sdr_ctx_errormsg (state_data->sdr_ctx));
       goto cleanup;
     }
   
@@ -542,7 +540,7 @@ ipmi_oem_sun_set_led (ipmi_oem_state_data_t *state_data)
       goto cleanup;
     }
   
-  if (ipmi_sdr_parse_entity_id_instance_type (state_data->sdr_parse_ctx,
+  if (ipmi_sdr_parse_entity_id_instance_type (state_data->sdr_ctx,
                                               sdr_record,
                                               sdr_record_len,
                                               NULL,
@@ -552,7 +550,7 @@ ipmi_oem_sun_set_led (ipmi_oem_state_data_t *state_data)
       pstdout_fprintf (state_data->pstate,
                        stderr,
                        "ipmi_sdr_parse_entity_id_and_instance: %s\n",
-                       ipmi_sdr_parse_ctx_errormsg (state_data->sdr_parse_ctx));
+                       ipmi_sdr_ctx_errormsg (state_data->sdr_ctx));
       goto cleanup;
     }
 
