@@ -30,6 +30,7 @@
 #else /* !HAVE_ARGP_H */
 #include "freeipmi-argp.h"
 #endif /* !HAVE_ARGP_H */
+#include <assert.h>
 
 #include "ipmi-pef-config.h"
 #include "ipmi-pef-config-argp.h"
@@ -65,7 +66,7 @@ static struct argp_option cmdline_options[] =
     ARGP_COMMON_HOSTRANGED_OPTIONS,
     ARGP_COMMON_OPTIONS_DEBUG,
     { "info",       INFO_KEY,       0, 0,
-      "Show general information about PEF configuration.", 30},
+      "Show general information about PEF configuration.", 40},
     CONFIG_ARGP_COMMON_OPTIONS,
     CONFIG_ARGP_COMMON_OPTIONS_LEGACY,
     CONFIG_ARGP_LAN_CHANNEL_OPTION,
@@ -87,9 +88,13 @@ static struct argp cmdline_config_file_argp = { cmdline_options,
 static error_t
 cmdline_parse (int key, char *arg, struct argp_state *state)
 {
-  struct ipmi_pef_config_arguments *cmd_args = state->input;
+  struct ipmi_pef_config_arguments *cmd_args;
   error_t ret;
 
+  assert (state);
+  
+  cmd_args = state->input;
+
   switch (key)
     {
     case INFO_KEY:
@@ -107,9 +112,7 @@ cmdline_parse (int key, char *arg, struct argp_state *state)
     default:
       ret = config_parse_opt (key, arg, &cmd_args->config_args);
       if (ret == ARGP_ERR_UNKNOWN)
-        ret = common_parse_opt (key, arg, &cmd_args->config_args.common);
-      if (ret == ARGP_ERR_UNKNOWN)
-        ret = hostrange_parse_opt (key, arg, &(cmd_args->config_args.hostrange));
+        ret = common_parse_opt (key, arg, &cmd_args->config_args.common_args);
       return (ret);
     }
 
@@ -121,21 +124,21 @@ _ipmi_pef_config_config_file_parse (struct ipmi_pef_config_arguments *cmd_args)
 {
   struct config_file_data_ipmi_pef_config config_file_data;
   
+  assert (cmd_args);
+
   memset (&config_file_data,
           '\0',
           sizeof (struct config_file_data_ipmi_pef_config));
   
-  if (config_file_parse (cmd_args->config_args.common.config_file,
+  if (config_file_parse (cmd_args->config_args.common_args.config_file,
                          0,
-                         &(cmd_args->config_args.common),
-                         NULL,
-                         &(cmd_args->config_args.hostrange),
+                         &(cmd_args->config_args.common_args),
                          CONFIG_FILE_INBAND | CONFIG_FILE_OUTOFBAND | CONFIG_FILE_HOSTRANGE,
                          CONFIG_FILE_TOOL_IPMI_PEF_CONFIG,
                          &config_file_data) < 0)
     {
       fprintf (stderr, "config_file_parse: %s\n", strerror (errno));
-      exit (1);
+      exit (EXIT_FAILURE);
     }
 
   if (config_file_data.verbose_count_count)
@@ -145,13 +148,15 @@ _ipmi_pef_config_config_file_parse (struct ipmi_pef_config_arguments *cmd_args)
 static void
 _ipmi_pef_config_args_validate (struct ipmi_pef_config_arguments *cmd_args)
 {
+  assert (cmd_args);
+
   if ((!cmd_args->config_args.action && !cmd_args->info)
       || (cmd_args->config_args.action && cmd_args->info)
       || cmd_args->config_args.action == -1)
     {
       fprintf (stderr,
                "Exactly one of --info, --checkout, --commit, --diff, or --listsections MUST be given\n");
-      exit (1);
+      exit (EXIT_FAILURE);
     }
 
   /* make dummy argument for args validate to pass */
@@ -164,9 +169,13 @@ _ipmi_pef_config_args_validate (struct ipmi_pef_config_arguments *cmd_args)
 void
 ipmi_pef_config_argp_parse (int argc, char **argv, struct ipmi_pef_config_arguments *cmd_args)
 {
+  assert (argc >= 0);
+  assert (argv);
+  assert (cmd_args);
+
   init_config_args (&(cmd_args->config_args));
-  init_common_cmd_args_admin (&(cmd_args->config_args.common));
-  init_hostrange_cmd_args (&(cmd_args->config_args.hostrange));
+  init_common_cmd_args_admin (&(cmd_args->config_args.common_args));
+
   cmd_args->info = 0;
 
   argp_parse (&cmdline_config_file_argp,
@@ -174,7 +183,7 @@ ipmi_pef_config_argp_parse (int argc, char **argv, struct ipmi_pef_config_argume
               argv,
               ARGP_IN_ORDER,
               NULL,
-              &(cmd_args->config_args.common));
+              &(cmd_args->config_args.common_args));
 
   _ipmi_pef_config_config_file_parse (cmd_args);
 
@@ -185,7 +194,7 @@ ipmi_pef_config_argp_parse (int argc, char **argv, struct ipmi_pef_config_argume
               NULL,
               cmd_args);
 
-  verify_common_cmd_args (&(cmd_args->config_args.common));
+  verify_common_cmd_args (&(cmd_args->config_args.common_args));
   _ipmi_pef_config_args_validate (cmd_args);
 }
 
