@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_SENSOR_TYPES_SPEC_H
-#define _IPMI_SENSOR_TYPES_SPEC_H
+#ifndef IPMI_SENSOR_TYPES_SPEC_H
+#define IPMI_SENSOR_TYPES_SPEC_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -88,4 +88,4 @@ extern const char *const ipmi_oem_sensor_type;
 }
 #endif
 
-#endif
+#endif /* IPMI_SENSOR_TYPES_SPEC_H */
