@@ -16,8 +16,8 @@
  * 
  */
 
-#ifndef _IPMI_RMCPPLUS_INTERFACE_TEMPLATES_H
-#define _IPMI_RMCPPLUS_INTERFACE_TEMPLATES_H
+#ifndef IPMI_RMCPPLUS_INTERFACE_TEMPLATES_H
+#define IPMI_RMCPPLUS_INTERFACE_TEMPLATES_H
 
 #ifdef __cplusplus
 extern "C" {
@@ -209,4 +209,4 @@ FIID Template: tmpl_rmcpplus_rakp_message_4
 }
 #endif
 
-#endif  /* _IPMI_RMCPPLUS_INTERFACE_TEMPLATES_H */
+#endif /* IPMI_RMCPPLUS_INTERFACE_TEMPLATES_H */
