@@ -43,6 +43,7 @@
 #include "freeipmi/util/ipmi-rmcpplus-util.h"
 #include "freeipmi/util/ipmi-util.h"
 
+#include "ipmi-network.h"
 #include "libcommon/ipmi-crypt.h"
 #include "libcommon/ipmi-fiid-util.h"
 #include "libcommon/ipmi-fill-util.h"
@@ -739,7 +740,7 @@ _construct_payload_confidentiality_aes_cbc_128 (uint8_t payload_type,
   uint8_t iv[IPMI_CRYPT_AES_CBC_128_IV_LENGTH];
   int iv_len;
   uint8_t payload_buf[IPMI_MAX_PAYLOAD_LENGTH];
-  uint8_t pad_len;
+  uint8_t pad_len, pad_tmp;
   int payload_len, cipher_keylen, cipher_blocklen, encrypt_len;
 
   /* Note: Confidentiality Key for AES_CBS_128 is K2 */
@@ -808,7 +809,11 @@ _construct_payload_confidentiality_aes_cbc_128 (uint8_t payload_type,
   /* Pad the data appropriately */
 
   /* +1 is for the pad length field */
-  pad_len = IPMI_CRYPT_AES_CBC_128_BLOCK_LENGTH - ((payload_len + 1) % IPMI_CRYPT_AES_CBC_128_BLOCK_LENGTH);
+  pad_tmp = ((payload_len + 1) % IPMI_CRYPT_AES_CBC_128_BLOCK_LENGTH);
+  if (pad_tmp)
+    pad_len = IPMI_CRYPT_AES_CBC_128_BLOCK_LENGTH - pad_tmp;
+  else
+    pad_len = 0;
 
   if ((payload_len + pad_len + 1) > IPMI_MAX_PAYLOAD_LENGTH)
     {
@@ -821,8 +826,8 @@ _construct_payload_confidentiality_aes_cbc_128 (uint8_t payload_type,
       unsigned int i;
       for (i = 0; i < pad_len; i++)
         payload_buf[payload_len + i] = i + 1;
-      payload_buf[payload_len + pad_len] = pad_len;
     }
+  payload_buf[payload_len + pad_len] = pad_len;
 
   /* +1 for pad length field */
   if ((encrypt_len = crypt_cipher_encrypt (IPMI_CRYPT_CIPHER_AES,
@@ -2647,3 +2652,44 @@ unassemble_ipmi_rmcpplus_pkt (uint8_t authentication_algorithm,
 
   return (0);
 }
+
+ssize_t
+ipmi_rmcpplus_sendto (int s,
+		      const void *buf,
+		      size_t len,
+		      int flags,
+		      const struct sockaddr *to,
+		      socklen_t tolen)
+{
+  ssize_t rv;
+
+  /* achu: Per specification table 13-8, no legacy padding for IPMI
+   * 2.0 packets
+   */
+
+  if (!buf
+      || !len)
+    {
+      SET_ERRNO (EINVAL);
+      return (-1);
+    }
+
+  if ((rv = sendto (s, buf, len, flags, to, tolen)) < 0)
+    {
+      ERRNO_TRACE (errno);
+      return (-1);
+    }
+
+  return (rv);
+}
+
+ssize_t
+ipmi_rmcpplus_recvfrom (int s,
+			void *buf,
+			size_t len,
+			int flags,
+			struct sockaddr *from,
+			socklen_t *fromlen)
+{
+  return (ipmi_network_recvfrom (s, buf, len, flags, from, fromlen));
+}
