@@ -16,19 +16,18 @@
  * 
  */
 
-#ifndef _IPMI_INTERPRET_CONFIG_SENSOR_H
-#define _IPMI_INTERPRET_CONFIG_SENSOR_H
+#ifndef IPMI_INTERPRET_CONFIG_SENSOR_H
+#define IPMI_INTERPRET_CONFIG_SENSOR_H
 
 #include "freeipmi/interpret/ipmi-interpret.h"
 
 #include "ipmi-interpret-defs.h"
 
-int ipmi_interpret_sensor_init (ipmi_interpret_ctx_t ctx);
+int interpret_sensor_init (ipmi_interpret_ctx_t ctx);
 
-void ipmi_interpret_sensor_destroy (ipmi_interpret_ctx_t ctx);
+void interpret_sensor_destroy (ipmi_interpret_ctx_t ctx);
 
-int ipmi_interpret_sensor_config_parse (ipmi_interpret_ctx_t ctx,
-                                        const char *sensor_config_file);
-
-#endif /* ipmi-interpret-config-sensor.h */
+int interpret_sensor_config_parse (ipmi_interpret_ctx_t ctx,
+				   const char *sensor_config_file);
 
+#endif /* IPMI_INTERPRET_CONFIG_SENSOR_H */
